@@ -1,4 +1,6 @@
 #!/usr/bin/env perl
+use strict;
+use warnings;
 
 # PERL_FUTURE_DEBUG=1 perl eg/tester.pl
 
@@ -9,14 +11,18 @@ use MIDI::RtController::Filter::Tonal ();
 
 my $input_name  = shift || 'tempopad'; # midi controller device
 my $output_name = shift || 'fluid';    # fluidsynth
+my $filter_name = shift || 'pedal_tone';
 
 my $rtc = MIDI::RtController->new(
     input  => $input_name,
     output => $output_name,
+    verbose => 1,
 );
 
 my $rtf = MIDI::RtController::Filter::Tonal->new(rtc => $rtc);
+# $rtf->feedback(4);
 
-$rtc->add_filter('pedal', [qw(note_on note_off)], $rtf->curry::pedal_tone);
+my $method = "curry::$filter_name";
+$rtc->add_filter($filter_name, [qw(note_on note_off)], $rtf->$method);
 
 $rtc->run;
